==> peg-e_1.1.2.orig.tar.bz2: peg-e-1.1.2/translations/pege_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Game Over</source>
        <translation>Partie terminée</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <location filename="../src/window.cpp" line="246"/>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="58"/>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>&amp;Restart Game</source>
        <translation>&amp;Redémarrer la partie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="68"/>
        <source>&amp;Details</source>
        <translation>&amp;Détails</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>Ctrl+z</source>
        <translation>Ctrl+z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>Shift+Ctrl+Z</source>
        <translation>Maj+Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="90"/>
        <source>&amp;Appearance</source>
        <translation>&amp;Apparence</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="94"/>
        <source>Charcoal</source>
        <translation>Marron</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="96"/>
        <source>Midnight</source>
        <translation>Bleu nuit</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Plum</source>
        <translation>Prune</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="98"/>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>Yellow</source>
        <translation>Jaune</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="117"/>
        <source>Custom...</source>
        <translation>Personnalisée...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>New Game</source>
        <translation>Nouveau jeu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <location filename="../src/window.cpp" line="225"/>
        <location filename="../src/window.cpp" line="317"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <location filename="../src/window.cpp" line="218"/>
        <location filename="../src/window.cpp" line="320"/>
        <source>Branch</source>
        <translation>Branche</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="167"/>
        <location filename="../src/window.cpp" line="221"/>
        <location filename="../src/window.cpp" line="323"/>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Random</source>
        <translation>Aléatoire</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>Algorithm:</source>
        <translation>Algorithme : </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="187"/>
        <source>Difficulty:</source>
        <translation>Difficulté :</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="188"/>
        <source>Seed:</source>
        <translation>Grain : </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Do you want to restart?</source>
        <translation>Voulez-vous redémarrer ?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algorithme : &lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulté : &lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Grain : &lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="243"/>
        <source>About Peg-E</source>
        <translation>À propos de Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="247"/>
        <source>Peg elimination game</source>
        <translation>Peg, un jeu d&apos;élimination</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="248"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="249"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utilise les icônes du thème &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> peg-e-1.3.5.tar.bz2: peg-e-1.3.5/translations/pege_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Partie terminée</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>&amp;Redémarrer la partie</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Détails</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>&amp;Apparence</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>Marron</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>Bleu nuit</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>Prune</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Jaune</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Personnalisée...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nouveau jeu</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>Branche</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aléatoire</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithme : </translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>Difficulté :</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Grain : </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>Voulez-vous redémarrer ?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algorithme : &lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulté : &lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Grain : &lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>À propos de Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>Peg, un jeu d&apos;élimination</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utilise les icônes du thème &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
